@@ -1,4 +1,22 @@
-/** \file */
+/** \file gphoto2-port-log.h
+ *
+ * Copyright © 2001 Lutz Müller <lutz@users.sf.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details. 
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
 #ifndef __GPHOTO2_PORT_PORTABILITY_H__
 #define __GPHOTO2_PORT_PORTABILITY_H__
 
@@ -11,6 +29,8 @@
  ************************************************************************/
 
 # include <windows.h>
+/* done by mingw/wine headers ... defined to struct ... tsaes*/
+#undef interface
 # include <sys/types.h>
 # include <sys/stat.h>
 # include <string.h>
@@ -36,7 +56,7 @@ typedef struct {
 } GPPORTWINDIR;
 
 /* Sleep functionality */
-# define GP_SYSTEM_SLEEP(_ms)	  do { Sleep(_ms) } while (0)
+# define GP_SYSTEM_SLEEP(_ms)	  do { Sleep(_ms); } while (0)
 
 /* Directory-oriented functions */
 # define gp_system_dir		  GPPORTWINDIR *
